# django-oss-storage changelog

## 1.0.0

- First production release
- Testing against Django 1.11

## 2.0.0

- Set OSS storage location based on STATIC_ROOT and MEDIA_ROOT, other than STATIC_URL and MEDIA_URL
- Add support for Django 5.1+
